<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Faceţi clic pe Înapoi la Aplicaţie</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Curăţare</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 articole</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Denumire fişier</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Încercaţi din nou</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Oprire</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschidere</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicare podcast pe YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titlu</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descriere</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tablă</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documente</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Stilou</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Fundaluri</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Schimbare fundal</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Repetare</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Precedent</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Pagina precedentă</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Următor</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Pagina următoare</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Administrare documente</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Navigare pe web</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Linie subţire</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Linie medie</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Linie groasă</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Ieşire</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Gumă</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Gumă mică</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Gumă medie</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Gumă mare</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Culoare</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Stânga</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Înainte</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dreapta</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Reîncărcare</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Reîncărcare pagina curentă</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Acasă</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Încărcare pagina de start</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Semne de carte</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Afişare semne de carte</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Semn de carte</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Adăugare semn de carte</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Afişare tablă</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Ştergere conţinut</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferinţe</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Afişare preferinţe</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliotecă</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Afişare bibliotecă</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Afişare desktop</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Afişare desktop computer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Mai mare</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Mărire</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Mai mic</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Micşorare</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Folder nou</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Creare folder nou</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Document nou</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Creare document nou</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importare</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importare document</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportare</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exportare document</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Deschidere în tablă</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Deschidere pagină în tablă</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicare</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplicare conţinut selectat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Ştergere conţinut selectat</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Adăugare la documente de lucru</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Adăugare conţinut selectat în Open document</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adăugare</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Adăugare conţinut în document</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Redenumire</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Redenumire conţinut</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Instrumente</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Afişare instrumente</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Ecran multiplu</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Format lat (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Utilizare format document lat (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Format normal (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Utilizare format document normal (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Format particularizat</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Utilizare format document particularizat</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Oprire încărcare</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Oprire încărcare pagină web</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Decupare</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiere</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lipire</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Oprire automată</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Punere prezentare pe oprire automată</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Tastatură virtuală</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Afişare tastatură virtuală</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Fundal deschis simplu</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Deschis</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Fundal deschis cu grilă</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Fundal închis simplu</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Închis</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Fundal închis cu grilă</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Înregistrare prezentare pe video</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Înregistrare</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Pornire înregistrare ecran</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Ştergere articole</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Ştergere toate articolele</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Ştergere adnotări</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Ştergere toate adnotările</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Ştergere pagină</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Ştergere toate elementele</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stilou</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Adnotare document</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Ştergere adnotare</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Evidenţiere</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Selector</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Selectare şi modificare obiecte</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Mână</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Derulare pagină</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Indicator laser</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Indicator laser virtual</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Desenare linii</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Scriere text</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Captuare</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturare parte ecran</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Adăugare la pagina curentă</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Adăugare articol la pagina curentă</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Adăugare la pagină nouă</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Adăugare articol la pagină nouă</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Adăugare la bibliotecă</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Adăugare articol la bibliotecă</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Pagini</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Creare pagină nouă</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Pagină nouă</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplicare pagină</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplicare pagină curentă</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importare pagină</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importare pagină externă</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauză</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pauză înregistrare podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Podcast Config</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Configurare înregistrare podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Blocare  flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Blocare conţinut flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Blocare web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Blocare conţinut web</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Capturare particularizată</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Capturare fereastră</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Capturare fereastră</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Incorporare conţinut web</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Capturare conţinut web incorporabil</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Afişare pe ecran</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Afişare ecran principal pe ecran de afişare</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Ştergere toate adnotările</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importare simulare eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Verificare actualizare</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Ieşire din OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Ascundere OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Ascundere aplicaţie OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Redare</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interacțiune cu articolele</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Ștergere fundal</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Eliminare fundal</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Autentificare obligatorie</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nume de utilizator:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parolă:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autentificare Proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Conectare pe Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nume de utilizator:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parolă:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Salvare nume de utilizator şi parolă pentru utilizare ulterioară</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>ID element =</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Conținutul nu este suportat în formatul de destinație.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Eliminare pagină</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Sunteți sigur că doriți să eliminați 1 pagină din documentul selectat &apos;%0&apos;?</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Dimensiune pagină</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Actualizare nouă disponibilă, doriţi să accesaţi pagina web?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Nu este disponibilă nicio actualizare</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Actualizare disponibilă</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizare</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Descărcare conţinut %1 nereuşită</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descărcare terminată</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Tip de instrument necunoscut %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Tip de conţinut necunoscut %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Adăugare articol</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Tot ce se suportă (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Ștergere pagina %1 din document</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Pagina %1 ștearsă</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Operațiunea de adăugare fișier nu a reușit: eroare copiere fișier</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grupare</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Degrupare</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Culoare</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Eroare adăugare imagine la bibliotecă</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>ImagineCapturată</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Caracteristici cache</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Culoare:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Formă:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dimensiune:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închidere</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturare parte de ecran</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Capturare ecran</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Afişare paletă stilou</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Afişare tablă pe ecran secundar</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Afişare desktop pe ecran secundar</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Folder nou</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Pagina %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Adăugare folder de imagini</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Afăugare imagini</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Adăugare pagini din fişier</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Duplicare document %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Document %1 copiat</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Eliminare pagină</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Eliminare document</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Sunteţi siguri că doriţi să eliminaţi documentul %1?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Golire coş de gunoi</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Sunteţi siguri că doriţi să goliţi coşul de gunoi?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Golire coş de gunoi</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Coş de gunoi golit</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Eliminare folder</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Sunteţi siguri că doriţi să eliminaţi folderul &apos;%1&apos; şi toate conţinuturile sale?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Nu s-a selectat niciun document!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Deschidere fişier suportat</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importare fişier %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Importare fişier nereuşită ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importare toate imaginile din folder</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Golire</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Coş de gunoi</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Deschidere document</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Adăugare toate imaginile la document</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Toate imaginile (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Selecţia nu conţine nicio imagine!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Sunteţi sigur că doriţi să eliminaţi %n pagină din documentul selectat &apos;%1&apos;?</numerusform>
            <numerusform>Sunteţi sigur că doriţi să eliminaţi %n pagini din documentul selectat &apos;%1&apos;?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Folderul nu conține niciun fișier imagine</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Documente fără titlu</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>imagini</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>înregistrări video</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>obiecte</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widget-uri</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Toate fişierele suportate (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Fişier %1 salvat</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Inserare pagina %1 din %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importare reuşită.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Importare fișier %1 reușită.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importare fișier %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Pagina %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Exportare nereuşită.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Acceptare</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Anulare</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Coş de gunoi</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 pagini copiate</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 pagini copiate</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Copiere pagina %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (copie)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Copiere pagina %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 pagini copiate</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Descărcare fişiere</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Au apărut atenționări în timpul exportului</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Exportare reuşită.</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exportare în IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportare ca fișier IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportare document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportare reuşită.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Exportare nereuşită.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Pagină</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportare ca fişier UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportare document ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportare reuşită.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Exportare %1 %2 din %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Exportare reuşită.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">Exportare nereuşită.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportare ca fişier PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exoprtare document ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportare reuşită.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportare în PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportare ca fişier PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportare document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportare reuşită.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Exportare pagina %1 din %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportare în PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exportare ca dată web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportare document...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportare reuşită.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Exportare nereuşită.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportare în browser web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Adăugare la pagină</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Setare ca fundal</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Adăugare la bibliotecă</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informaţii despre obiect</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Adăugare la favorite</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Distribuire</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Înapoi la folder</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Eliminare din favorite</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Creare folder nou</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Rescanare sistem de fișiere</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>ImagineImportată</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Înregistrări audio</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filme</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagini</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animaţii</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interactivităţi</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplicaţii</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Căutare web</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Coş de gunoi</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Acceptare</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Introducere un nume de folder nou</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Încărcare</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Blocat</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Vizibil pe ecran extins</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Blocat</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Vizibil pe ecran extins</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Accesare sursă conţinut</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Setare ca fundal</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Tipărire text aici&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Culoare text</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Editabil</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Încărcare ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Îngheţat</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transformare în instrument</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Format de fişier comun (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importare fişier %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Importare fişier %1 nereuşită.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importare reuşită.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Importare nereuşită.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importare fişier %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importare reuşită.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Importare fişier %1 nereuşită.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Format imagine (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Document în format portabil (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Importare PDF nereuşită.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importare pagina %1 din %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Eroare în timpul publicării înregistrării video pe intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publicare pe intranet în curs %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publicare</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Intrare</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nu</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Închidere</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Introduceţi numele de utilizator şi parola pentru &quot;%1&quot; la %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Conectare nereuşită pe Proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Erori SSL:

%1

%2

Doriţi să ignoraţi aceste erori pentru acest host?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nu</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Anulare</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(copie)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Pierdere depozit de documente</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Engleză</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Rusă</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Germană</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Franceză</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Franceză elvețiană</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Pornire codificator nereuşită ...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Nu este disponibil niciun codificator de podcast ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Partea %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>pe desktopul dumneavoastră ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>în folderul %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast creat %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Eroare înregistrare podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Intrare audio implicită</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Nicio înregistrare audio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Mic</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mediu</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Mare</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publicare pe Intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publicare pe YouTube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versiune:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Markerul este sensibil la apăsare</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Conectare Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Nume de utilizator:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Parolă:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publicare document pe web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titlu:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Descriere:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publicare</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Filmele mele</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Generare previzualizare miniaturi ...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniaturi generate ...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Mască</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Riglă</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Compas</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Raportor</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Echer</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupă</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Toată pagina</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Actualizator documente</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>fişiere necesită o actualizare.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Cale de acces pentru copii de rezervă:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Navigare</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizare</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Selectare fişier cu copii de rezervă</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Fişiere actualizate cu succes!
Vă rugăm să reporniţi aplicaţia pentru a accesa documentele actualizate.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>O eroare a intervenit în timpul actualizării. Fişierele nu au fost afectate.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Rezultate actualizare fişiere</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Actualizare fişier</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Vă rugăm să aşteptaţi, procesul de importare va începe în curând...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Reaminteşte-mi mai târziu</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Încărcare...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 apelate (metodă=%1, status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Autentificare YouTube nereuşită.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Eroare în timpul încărcării înregistrării video pe YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Încărcare pe YouTube în curs %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Încărcare</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Autoturisme &amp; vehicule</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzică</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Animale de companie &amp; Animale</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sporturi</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Călătorie &amp; Evenimente</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Jocuri</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Comedie</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Oameni &amp; Bloguri</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Noutăţi &amp; Politică</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Divertisment</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Educaţie</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Cum se face &amp; Stil</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Non-profituri &amp; Activism</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Ştiinţă &amp; Tehnologie</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Ştergere</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Salvare fişier</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Descărcare anulată: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Eroare deschidere fişier salvat: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Eroare salvare: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Eroare de reţea: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secunde</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minute</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 rămase</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 din %2 (%3/sec) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 din %2 - Întrerupte</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>biţi</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 descărcare</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 descărcări</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titlu</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresă</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Astăzi mai devreme</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 articole</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nou &amp;Tab</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Clonare tab</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Închidere tab</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Închidere &amp;Alte taburi</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Reîncărcare tab</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Reîncărcare toate tab-urile</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Tab-uri recent închise</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(fără titlu)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Căutare</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Nicio căutare recentă</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Căutări recente</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Ştergere toate căutările recente</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Descărcare</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Adăugare la documentul curent</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Eroare încărcare pagină: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Deschidere în tab nou</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicare podcast pe YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titlu</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descriere</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Cuvinte cheie</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Nume de utilizator YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Parolă YouTube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Făcând clic pe&apos;Încărcare,&apos; certificaţi faptul că deţineţi toate drepturile asupra conţinutului sau că sunteţi autorizat de titular să faceţi public conţinutul pe YouTube şi că este conform în celelalte privinţe cu Termenii de utilizare pentru YouTube de pe&lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Pe fundal deschis</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Pe fundal închis</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacitate</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Grosime linie</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medie</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Groasă</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Subţire</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Stiloul este sensibil la apăsare</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titlu</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descriere</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Titlu</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Descriere</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferinţe</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versiune : ...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Setări implicite</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Afişare</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Afişare pagină cu browser extern</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Pagina de start:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Tastatură virtuală</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Dimensiune buton tastatură:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Bară de instrumente</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Poziţionat în partea de sus (recomandat pentru tablete)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Poziţionat în partea de jos (recomandat pentru table albe)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Afişare text sub buton</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Paletă stilou</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Orizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stilou</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Actualizare software</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Verificare actualizare software la lansare</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenţe</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Reţea</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Afişare conţinut pagină de web intern pe ecranul secundar sau pe proiector</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Afişare multiplă</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Schimbare control afişare cu vizualizare afişare</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Modul în care se porneşte: </translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tablă</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Utilizator Proxy:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Parolă:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Credite</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Pe fundal închis</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Opacitate</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Pe fundal deschis</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Blocare flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Selectaţi un flash pentru blocare</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nume aplicaţie</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Creare aplicaţie</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
